/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-10-31 10:59:58.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.api.provider;

import cn.com.qmth.examcloud.commons.api.HandleSyncCloudService;
import cn.com.qmth.examcloud.commons.api.request.*;
import cn.com.qmth.examcloud.commons.api.response.*;
import cn.com.qmth.examcloud.commons.web.support.ControllerSupport;
import cn.com.qmth.examcloud.core.print.enums.ExamType;
import cn.com.qmth.examcloud.core.print.service.CoursePaperService;
import cn.com.qmth.examcloud.core.print.service.CourseStatisticService;
import cn.com.qmth.examcloud.core.print.service.ExamStructureService;
import cn.com.qmth.examcloud.core.print.service.PrintingProjectService;
import cn.com.qmth.examcloud.core.print.service.bean.common.ExamInfo;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 数据同步相关接口
 *
 * @author: fengdesheng
 * @since: 2018/10/31
 */
@RestController
@RequestMapping("${$rmp.cloud.print}/data")
public class SyncCloudServiceProvider extends ControllerSupport implements HandleSyncCloudService {
    @Autowired
    private PrintingProjectService printingProjectService;
    @Autowired
    private ExamStructureService examStructureService;
    @Autowired
    private CoursePaperService coursePaperService;
    @Autowired
    private CourseStatisticService courseStatisticService;

    /**
     * 同步学校机构
     */
    @PostMapping("/syncOrg")
    public SyncOrgResp syncOrg(@RequestBody SyncOrgReq req) {
        if (StringUtils.isNotBlank(req.getName())) {
            printingProjectService.syncOrgNameByOrgId(req.getRootId(), req.getName());
            examStructureService.syncOrgNameByOrgId(req.getRootId(), req.getName());
        }
        return new SyncOrgResp();
    }

    /**
     * 同步考试
     */
    @PostMapping("syncExam")
    public SyncExamResp syncExam(@RequestBody SyncExamReq req) {
        if (StringUtils.isNotBlank(req.getName())) {
            printingProjectService.syncExamNameByExamId(req.getId(), req.getName());
            examStructureService.syncExamNameByExamId(req.getId(), req.getName());

            if (ExamType.isTradition(req.getExamType())) {
                ExamInfo info = new ExamInfo(req.getRootOrgId(), req.getRootOrgName(), req.getId(), req.getName());
                printingProjectService.syncPrintingProject(info);
            }
        }
        return new SyncExamResp();
    }

    /**
     * 同步考生
     */
    @PostMapping("/syncExamStudent")
    public SyncExamStudentResp syncExamStudent(@RequestBody SyncExamStudentReq req) {
        return new SyncExamStudentResp();
    }

    /**
     * 同步学生
     */
    @PostMapping("/syncStudent")
    public SyncStudentResp syncStudent(@RequestBody SyncStudentReq req) {
        return new SyncStudentResp();
    }

    /**
     * 同步专业
     */
    @PostMapping("/syncCourse")
    public SyncCourseResp syncCourse(@RequestBody SyncCourseReq req) {
        if (StringUtils.isNotBlank(req.getName())) {
            coursePaperService.syncCourseNameByCourseId(req.getId(), req.getName());
            courseStatisticService.syncCourseNameByCourseId(req.getId(), req.getName());
        }
        return new SyncCourseResp();
    }

    /**
     * 同步专业
     */
    @PostMapping("syncSpecialty")
    public SyncSpecialtyResp syncSpecialty(@RequestBody SyncSpecialtyReq req) {
        return new SyncSpecialtyResp();
    }

    @PostMapping("syncUser")
    public SyncUserResp syncUser(SyncUserReq req) {
        if (StringUtils.isNotBlank(req.getName())) {
            printingProjectService.syncPmNameByPmId(req.getId(), req.getName());
            printingProjectService.syncSupplierNameBySupplierId(req.getId(), req.getName());
        }
        return new SyncUserResp();
    }

}