/*
 * *************************************************
 * Copyright (c) 2018 QMTH. All Rights Reserved.
 * Created by Deason on 2018-11-23 17:52:03.
 * *************************************************
 */

package cn.com.qmth.examcloud.core.print.service.impl;

import cn.com.qmth.examcloud.core.print.common.jpa.SqlWrapper;
import cn.com.qmth.examcloud.core.print.service.StatisticService;
import cn.com.qmth.examcloud.core.print.service.bean.common.ExamCourseInfo;
import cn.com.qmth.examcloud.core.print.service.bean.common.ExamInfo;
import cn.com.qmth.examcloud.core.print.service.bean.questionstructure.PaperQuestionStructureInfo;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.jdbc.core.BeanPropertyRowMapper;
import org.springframework.jdbc.core.JdbcTemplate;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * @author: fengdesheng
 * @since: 2018/11/7
 */
@Service
public class StatisticServiceImpl implements StatisticService {
    private static final Logger log = LoggerFactory.getLogger(StatisticServiceImpl.class);
    @Autowired
    private JdbcTemplate jdbcTemplate;

    @Override
    public List<ExamInfo> findExams(String examType) {
        //暂时直接查库，待“考务”接口提供后改为通过接口获取数据
        SqlWrapper sql = new SqlWrapper()
                .select("em.id examId,em.name examName,em.root_org_id orgId,org.name orgName").from("ec_e_exam em")
                .innerJoin("ec_b_org org").on("org.id", "em.root_org_id");
        if (StringUtils.isNotBlank(examType)) {
            //sql.where().eq("em.exam_type", examType); todo 仅测试，临时注释
        }
        sql.orderBy("em.id", false);
        return jdbcTemplate.query(sql.build(), new BeanPropertyRowMapper(ExamInfo.class));
    }

    @Override
    public List<ExamCourseInfo> findExamCourses(Long orgId, Long examId) {
        return this.findExamCourses(orgId, examId, null, null);
    }

    @Override
    public List<ExamCourseInfo> findExamCourses(Long orgId, Long examId, Long courseId, String paperType) {
        //暂时直接查库，待“考务”接口提供后改为通过接口获取数据
        SqlWrapper sql = new SqlWrapper()
                .select("root_org_id orgId,exam_id,course_id,course_code,course_name,paper_type,count(course_code) totalStudent")
                .from("ec_e_exam_student") //old ecs_exam_student
                .where()
                .eq("root_org_id", orgId)
                .and().eq("exam_id", examId);
        if (courseId != null) {
            sql.and().eq("course_id", courseId);
        }
        if (StringUtils.isNotBlank(paperType)) {
            sql.and().eq("paper_type", paperType);
        }
        sql.groupBy("course_id,paper_type");
        return jdbcTemplate.query(sql.build(), new BeanPropertyRowMapper(ExamCourseInfo.class));
    }

    @Override
    public PaperQuestionStructureInfo findStructureByPaperId(Long examId, String paperId) {
        PaperQuestionStructureInfo info = new PaperQuestionStructureInfo();
        //todo
        return info;
    }

}